package com.ruoyi.yiqi.controller;

import cn.hutool.core.bean.BeanUtil;
import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.write.style.column.LongestMatchColumnWidthStyleStrategy;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.convert.ExcelBigNumberConvert;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.file.FileUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.obs.ObsService;
import com.ruoyi.yiqi.entity.*;
import com.ruoyi.yiqi.service.IYqGAreaService;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.io.IOException;
import java.util.*;

/**
 * 小区Controller
 *
 * @author ruoyi
 * @date 2021-11-15
 */
@Validated
@RequiredArgsConstructor(onConstructor_ = @Autowired)
@RestController
@RequestMapping("/yq/gas/area")
public class YqGAreaController extends BaseController {

    private final IYqGAreaService iGAreaService;

    private final ObsService obsService;

    private String bfb="0";
    private String message;

    /**
     * 查询小区列表
     */
    @GetMapping("/list")
    public TableDataInfo<YqGArea> list(@Validated(QueryGroup.class) YqGArea bo) {
        return iGAreaService.queryPageList(bo);
    }

    /**
     * 导出小区列表
     */
    @Log(title = "小区", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public void export(@Validated YqGArea bo, HttpServletResponse response) {
        List<GExportVo> list = iGAreaService.getExportList();
        ExcelUtil.exportExcel(list, "小区", GExportVo.class, response);
    }
    /**
     * 导出小区列表
     */
    @Log(title = "小区", businessType = BusinessType.EXPORT)
    @GetMapping("/exports")
    public void exports(@Validated YqGArea bo, HttpServletResponse response) {
        String filename = "";
        filename = iGAreaService.getDictNameOfAffiliatedPackage(bo);
        List<GExportsVo> list = iGAreaService.getExport(bo);
        try {
            response.reset();
            FileUtils.setAttachmentResponseHeader(response, filename+ ".xlsx");
            response.setContentType("application/vnd.openxmlformats-officedocument.spreadsheetml.sheet;charset=UTF-8");
            ServletOutputStream os = response.getOutputStream();
            EasyExcel.write(os, GExportsVo.class)
                    .autoCloseStream(false)
                    // 自动适配
                    .registerWriteHandler(new LongestMatchColumnWidthStyleStrategy())
                    // 大数值自动转换 防止失真
                    .registerConverter(new ExcelBigNumberConvert())
                    .sheet(filename).doWrite(list);
        } catch (IOException e) {
            throw new RuntimeException("导出Excel异常");
        }

    }
    @PostMapping("/importData")
    public synchronized R<Void> importData(@RequestPart("file") MultipartFile file, boolean updateSupport) throws Exception {
        List<GImportVo> listVo = ExcelUtil.importExcel(file.getInputStream(), GImportVo.class);
        List<GImportVo> list = BeanUtil.copyToList(listVo, GImportVo.class);
        String operName = getUsername();
        if(Double.valueOf(bfb)<=0){
            forImportData(list,true,operName,0,0);
        }
        return R.ok(message);
    }

    public void forImportData(List<GImportVo> list, Boolean isUpdateSupport, String operName,int n,int okNum) throws Exception
    {
        try{
            Map<String,Object> ret = iGAreaService.importUser(list, isUpdateSupport, operName,n,okNum);//list, updateSupport, operName，第几条
            if(Boolean.valueOf(ret.get("is_ok").toString())){
                bfb = ret.get("bfb").toString();
                forImportData(list,isUpdateSupport,operName,Integer.valueOf(ret.get("n").toString()),Integer.valueOf(ret.get("okNum").toString()));
            }else{
                message = ret.get("okMsg").toString();
            }
        } catch (Exception e) {
            message = e.getMessage();
        }
    }

    /**
     * 进度条刷新，
     */
    @GetMapping(value = "/flushProgress")
    public R<Map> flushProgress() throws Exception
    {
        Map<String,String> ret = new HashMap<>();
        ret.put("bfb",bfb);
        ret.put("message",message);
        return R.ok(ret);
    }

    /**
     * 结束进度条刷新，
     */
    @GetMapping(value = "/clearFlushProgress")
    public R<Void> clearFlushProgress() throws Exception
    {
        bfb="0";
        message="";
        return R.ok();
    }


    @PostMapping("/importApprovalExcel")
    public R<Void> importApprovalExcel(@RequestPart("file") MultipartFile file, boolean updateSupport) throws Exception {
        List<GImportVo> listVo = ExcelUtil.importExcel(file.getInputStream(), GImportVo.class);
        List<GImportVo> list = BeanUtil.copyToList(listVo, GImportVo.class);
        String operName = getUsername();
        String message = iGAreaService.importApprovalExcel(list, updateSupport, operName);
        return R.ok(message);
    }
    @PostMapping("/importDataA")
    public R<Void> importDataA(@RequestPart("file") MultipartFile file, boolean updateSupport) throws Exception {
        List<GImportVo> listVo = ExcelUtil.importExcel(file.getInputStream(), GImportVo.class);
        List<GImportVo> list = BeanUtil.copyToList(listVo, GImportVo.class);
        String operName = getUsername();
        String message = iGAreaService.importUserA(list, updateSupport, operName);
        return R.ok(message);
    }
    @GetMapping("/importTemplate")
    public void importTemplate(HttpServletResponse response) {
        ExcelUtil.exportExcel(new ArrayList<>(), "小区", GImportVo.class, response);
    }
    /**
     * 获取小区详细信息
     */
    @GetMapping("/{id}")
    public R<YqGArea> getInfo(@NotNull(message = "主键不能为空")
                                                  @PathVariable("id") Long id) {
        return R.ok(iGAreaService.queryById(id));
    }

    /**
     * 新增小区
     */
    @Log(title = "小区", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Boolean> add(@Validated(AddGroup.class) @RequestBody YqGArea bo) {
        return R.ok(iGAreaService.insertByBo(bo));
//        return toAjax(iGAreaService.insertByBo(bo) ? 1 : 0);
    }

    /**
     * 修改小区
     */
    @Log(title = "小区", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody YqGArea bo) {
        return toAjax(iGAreaService.updateByBo(bo) ? 1 : 0);
    }

    /**
     * 删除小区
     */
    @Log(title = "小区" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                                       @PathVariable Long[] ids) {
        return toAjax(iGAreaService.deleteWithValidByIds(Arrays.asList(ids), true) ? 1 : 0);
    }

    /**
     * 小区列表查询
     * @param bo
     * @return
     */
    @GetMapping("/getList")
    public TableDataInfo<YqGArea> getList(@Validated(QueryGroup.class) YqGArea bo) {
        return iGAreaService.getList(bo);
    }

    /**
     * 小区下拉
     * @return
     */
    @GetMapping("/getArea")
    public R getArea() {
        return R.ok(iGAreaService.getArea());
    }

    /**
     *合格/不合格统计-小区
     * @param areaId
     * @return
     */
    @GetMapping("/getExamineArea")
    public R getExamineArea(Long areaId) {
        return R.ok(iGAreaService.getExamineArea(areaId));
    }

    /**
     * 服务统计-针对小区
     * @param id
     * @return
     */
    @GetMapping("/getExamineServe")
    public R getExamineServe(Long id) {
        return R.ok(iGAreaService.getExamineServe(id));
    }

    /**
     * 批量下载生成文件夹打压缩包
     */
    @GetMapping("/upload")
    @Log(title = "小区照片下载", businessType = BusinessType.EXPORT)
    public void upload(HttpServletRequest request, HttpServletResponse response, @RequestParam Long id) throws Exception {
        iGAreaService.upload(request, response, id);
    }

    /**
     * 小区汇总统计
     * @param areaId
     * @return
     */
    @GetMapping("/getAreaSum")
    public R getAreaSum(Long areaId) {
        return R.ok(iGAreaService.getAreaSum(areaId));
    }

    @GetMapping("/releaseIs")
    public R releaseIs(Long id) {
        iGAreaService.releaseIs(id);
        // 小区下所有照片
        List<String> list = iGAreaService.getPhoto(id);
        obsService.deleteFiles(list);
        iGAreaService.deleteDirectory(iGAreaService.getById(id).getName());
        return R.ok();
    }

    /**
     *小区唯一校验
     * @param name
     * @return
     */
    @GetMapping("/getForName")
    public R getForName(String name,String id) {
        return R.ok(iGAreaService.getForName(name,id));
    }

    @GetMapping("/getExportHouse")
    public void getExportHouse(Long areaId, HttpServletResponse response) {
        List<GAreaExportVo> list = iGAreaService.getExportHouse(areaId);
        ExcelUtil.exportExcel(list, "小区完工率", GAreaExportVo.class, response);
    }
}
