package com.ruoyi.yiqi.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.yiqi.entity.YqGBuilding;
import com.ruoyi.yiqi.service.IYqGBuildingService;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.util.Arrays;
import java.util.List;

/**
 * 楼宇Controller
 *
 * @author ruoyi
 * @date 2021-11-15
 */
@Validated
@RequiredArgsConstructor(onConstructor_ = @Autowired)
@RestController
@RequestMapping("/yq/gas/building")
public class YqGBuildingController extends BaseController {

    private final IYqGBuildingService iGBuildingService;

    /**
     * 查询楼宇列表
     */
    @GetMapping("/list")
    public TableDataInfo<YqGBuilding> list(@Validated(QueryGroup.class) YqGBuilding bo) {
        return iGBuildingService.queryPageList(bo);
    }

    /**
     * 导出楼宇列表
     */
    @Log(title = "楼宇", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public void export(@Validated YqGBuilding bo, HttpServletResponse response) {
        List<YqGBuilding> list = iGBuildingService.queryList(bo);
        ExcelUtil.exportExcel(list, "楼宇", YqGBuilding.class, response);
    }

    /**
     * 获取楼宇详细信息
     */
    @GetMapping("/{id}")
    public R<YqGBuilding> getInfo(@NotNull(message = "主键不能为空")
                                                  @PathVariable("id") Long id) {
        return R.ok(iGBuildingService.queryById(id));
    }

    /**
     * 新增楼宇
     */
    @Log(title = "楼宇", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Boolean> add(@Validated(AddGroup.class) @RequestBody YqGBuilding bo) {
        return R.ok(iGBuildingService.insertByBo(bo));
//        return toAjax(iGBuildingService.insertByBo(bo) ? 1 : 0);
    }

    /**
     * 修改楼宇
     */
    @Log(title = "楼宇", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody YqGBuilding bo) {
        return toAjax(iGBuildingService.updateByBo(bo) ? 1 : 0);
    }

    /**
     * 删除楼宇
     */
    @Log(title = "楼宇" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                                       @PathVariable Long[] ids) {
        return toAjax(iGBuildingService.deleteWithValidByIds(Arrays.asList(ids), true) ? 1 : 0);
    }

    @GetMapping("/getList")
    public TableDataInfo<YqGBuilding> getList(@Validated(QueryGroup.class) YqGBuilding bo) {
        return iGBuildingService.getList(bo);
    }

    @GetMapping("/getBuilding")
    public R getBuilding(Long areaId) {
        return R.ok(iGBuildingService.getBuilding(areaId));
    }
}
