package com.ruoyi.yiqi.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.yiqi.entity.YqGUnit;
import com.ruoyi.yiqi.service.IYqGUnitService;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.util.Arrays;
import java.util.List;

/**
 * 单元Controller
 *
 * @author ruoyi
 * @date 2021-11-15
 */
@Validated
@RequiredArgsConstructor(onConstructor_ = @Autowired)
@RestController
@RequestMapping("/yq/gas/unit")
public class YqGUnitController extends BaseController {

    private final IYqGUnitService iGUnitService;

    /**
     * 查询单元列表
     */
    @GetMapping("/list")
    public TableDataInfo<YqGUnit> list(@Validated(QueryGroup.class) YqGUnit bo) {
        return iGUnitService.queryPageList(bo);
    }

    /**
     * 导出单元列表
     */
    @Log(title = "单元", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public void export(@Validated YqGUnit bo, HttpServletResponse response) {
        List<YqGUnit> list = iGUnitService.queryList(bo);
        ExcelUtil.exportExcel(list, "单元", YqGUnit.class, response);
    }

    /**
     * 获取单元详细信息
     */
    @GetMapping("/{id}")
    public R<YqGUnit> getInfo(@NotNull(message = "主键不能为空")
                                                  @PathVariable("id") Long id) {
        return R.ok(iGUnitService.getById(id));
    }

    /**
     * 新增单元
     */
    @Log(title = "单元", businessType = BusinessType.INSERT)
    @RepeatSubmit()
    @PostMapping()
    public R<Boolean> add(@Validated(AddGroup.class) @RequestBody YqGUnit bo) {
        return R.ok(iGUnitService.insertByBo(bo));
//        return toAjax(iGUnitService.insertByBo(bo) ? 1 : 0);
    }

    /**
     * 修改单元
     */
    @Log(title = "单元", businessType = BusinessType.UPDATE)
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody YqGUnit bo) {
        return toAjax(iGUnitService.updateByBo(bo) ? 1 : 0);
    }

    /**
     * 删除单元
     */
    @Log(title = "单元" , businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                                       @PathVariable Long[] ids) {
        return toAjax(iGUnitService.deleteWithValidByIds(Arrays.asList(ids), true) ? 1 : 0);
    }

    @GetMapping("/getList")
    public TableDataInfo<YqGUnit> getList(@Validated(QueryGroup.class) YqGUnit bo) {
        return iGUnitService.getList(bo);
    }

    @GetMapping("/getUnit")
    public R getUnit(Long buildingId) {
        return R.ok(iGUnitService.getUnit(buildingId));
    }
}
