package com.ruoyi.yiqi.controller;

import com.ruoyi.common.annotation.RepeatSubmit;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.core.validate.AddGroup;
import com.ruoyi.common.core.validate.EditGroup;
import com.ruoyi.common.core.validate.QueryGroup;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.yiqi.entity.YqGUser;
import com.ruoyi.yiqi.service.IYqGUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.util.Arrays;
import java.util.List;

/**
 * 用户Controller
 *
 * @author ruoyi
 * @date 2021-11-12
 */
@Validated
@RestController
@RequestMapping("/yq/gas/user")
public class YqGUserController extends BaseController {

    @Autowired
    private IYqGUserService iGUserService;

    /**
     * 查询用户列表
     */
    @GetMapping("/list")
    public TableDataInfo<YqGUser> list(@Validated(QueryGroup.class) YqGUser bo) {
        return iGUserService.queryPageList(bo);
    }

    /**
     * 导出用户列表
     */
    @GetMapping("/export")
    public void export(@Validated YqGUser bo, HttpServletResponse response) {
        List<YqGUser> list = iGUserService.queryList(bo);
        ExcelUtil.exportExcel(list, "用户", YqGUser.class, response);
    }

    /**
     * 获取用户详细信息
     */
    @GetMapping("/{id}")
    public R<YqGUser> getInfo(@NotNull(message = "主键不能为空")
                                                  @PathVariable("id") Long id) {
        return R.ok(iGUserService.queryById(id));
    }

    /**
     * 新增用户
     */
    @RepeatSubmit()
    @PostMapping()
    public R<Void> add(@Validated(AddGroup.class) @RequestBody YqGUser bo) {
        return toAjax(iGUserService.insertByBo(bo) ? 1 : 0);
    }

    /**
     * 修改用户
     */
    @RepeatSubmit()
    @PutMapping()
    public R<Void> edit(@Validated(EditGroup.class) @RequestBody YqGUser bo) {
        return toAjax(iGUserService.updateByBo(bo) ? 1 : 0);
    }

    /**
     * 删除用户
     */
    @DeleteMapping("/{ids}")
    public R<Void> remove(@NotEmpty(message = "主键不能为空")
                                       @PathVariable Long[] ids) {
        return toAjax(iGUserService.deleteWithValidByIds(Arrays.asList(ids), true) ? 1 : 0);
    }

    /**
     * 列表查询
     * @param bo
     * @return
     */
    @GetMapping("/getList")
    public TableDataInfo<YqGUser> getList(@Validated(QueryGroup.class) YqGUser bo) {
        return iGUserService.getList(bo);
    }

    /**
     * 工人下拉
     * @return
     */
    @GetMapping("/getWorker")
    public R getWorker() {
        return R.ok(iGUserService.getWorker());
    }

    /**
     * 黑名单列表
     * @param bo
     * @return
     */
    @GetMapping("/getBlacklist")
    public TableDataInfo<YqGUser> getBlacklist(@Validated(QueryGroup.class) YqGUser bo) {
        return iGUserService.getBlacklist(bo);
    }

    /**
     * 合格/不合格统计-工长
     * @return
     */
    @GetMapping("/getExamineForeman")
    public R getExamineForeman(Long foremanId) {
        return R.ok(iGUserService.getExamineForeman(foremanId));
    }

    /**
     * 合格/不合格统计-工人
     * @return
     */
    @GetMapping("/getExamineWorker")
    public R getExamineWorker(Long workerId) {
        return R.ok(iGUserService.getExamineWorker(workerId));
    }

    /**
     * 手机号唯一校验
     * @param phone
     * @return
     */
    @GetMapping("/getForPhone")
    public R getForPhone(Long phone, String id) {
        return R.ok(iGUserService.getForPhone(phone,id));
    }

    /**
     *工号唯一校验
     * @param jobNum
     * @return
     */
    @GetMapping("/getForJobnum")
    public R getForJobnum(String jobNum,String id) {
        return R.ok(iGUserService.getForJobnum(jobNum,id));
    }
}
